import { Image, StyleSheet, Text, TouchableWithoutFeedback, View } from 'react-native'
import React, { useContext } from 'react'
import colors from '../../../constants/colors'
import images from '../../../assets/images/images'
import { horizontalScale, moderateScale, screenWidth, verticalScale } from '../../../constants/metrics'
import fonts from '../../../constants/fonts'
import { ThemeContext } from '../../../context/theme.context'


const VerticalNewsCard = ({ image, headline, tagline, style, onPress }) => {

    const theme = useContext(ThemeContext)
    const currentTheme = theme.state.theme

    const styles = StyleSheet.create({
        cardContainer: {
            width: 'auto',
            maxWidth: horizontalScale(210),
            backgroundColor: currentTheme === 'light' ? colors().white : colors().black_variant ,
            borderRadius: moderateScale(4),
            height: verticalScale(300),
            maxHeight: verticalScale(300),
            marginRight: horizontalScale(16),
            paddingBottom: verticalScale(24),
            elevation: 4
        },
        textContainer: {
            width: horizontalScale(210),
            maxWidth: screenWidth,
            height: "50%",
            paddingHorizontal: horizontalScale(14),
            paddingVertical: verticalScale(8)
        },
        imagesContainer: {
            width: '100%',
            height: '50%'

        },
        image: {
            borderRadius: moderateScale(4),
            width: '100%',
            height: '100%'
        },
        headline: {
            fontFamily: fonts.type.medium,
            textDecorationLine: 'underline',
            fontSize: 14,
            color: colors().recessive ,
            paddingBottom: 8
        },
        tagline: {
            fontSize: 12,
            fontFamily: fonts.type.regular,
            maxHeight: '40%',
            overflow: 'hidden',
            color: colors().recessive
            
        }
    })
    return (
        <TouchableWithoutFeedback onPress={onPress}>
            <View style={[styles.cardContainer, style]}>
                <View style={styles.imagesContainer}>
                    <Image source={image ?? images.verticalCard} style={styles.image} />
                </View>
                <View style={styles.textContainer}>
                    <Text style={styles.headline}> {headline ?? "Aston Villa avoid relegation on final day"}</Text>
                    <Text style={styles.tagline}>{tagline ?? "The reason behind their disappointment is that iPir disappointment is that iPhonsers have been."}</Text>
                </View>
            </View>
        </TouchableWithoutFeedback>
    )
}

export default VerticalNewsCard

