import { StyleSheet, Text, View, ScrollView } from 'react-native';
import React, { useContext, useEffect } from 'react';
import { ToggleButton } from 'react-native-paper';
import fonts from '../../../constants/fonts';
import colors from '../../../constants/colors';
import HorizontalNewsCardVariant from '../../molecules/Cards/HorizontalNewsCardVariant';
import { PAGINATE_BY, getScreenType, useConstructor } from '../../../constants/functions';
import SectionHeader from '../../molecules/Header/SectionHeader';
import { horizontalScale, moderateScale, verticalScale } from '../../../constants/metrics';
import { ThemeContext } from '../../../context/theme.context';


// * API Handling

const CategorySection = ({ navigation }) => {

  const theme = useContext(ThemeContext)
  const currentTheme = theme.state.theme

  const [news, setNews] = React.useState({ all: [] });
  const updateNewsByCategories = (key, value) => {
    setNews(prevObject => ({
      ...prevObject,
      [key]: value,
    }));
  };

  const [categoryValue, setCategoryValue] = React.useState('');
  const [categories, setCategories] = React.useState([]);
  const fetchCategories = () => {
    fetch(`http://www.newscout.in/api/v1/menus/?domain=newscout`)
      .then(res => res.json())
      .then(json => {
        let categoriesHeading = json.body.results.map(
          item => item.heading.name,
        );
        setCategories(categoriesHeading);
        setNews({});
        setNews(
          categoriesHeading.reduce(
            (result, key) => ({ ...result, [key]: [] }),
            {},
          ),
        ),
          setCategoryValue(categoriesHeading[0]);
        return categoriesHeading;
      })
      .then(cats => {
        cats.forEach(cat => {
          fetchNews(cat);
        });
        return cats;
      })
      .catch(err => console.log(err))
      .finally(() => console.log('Fetch Categories Executed'));
  };

  const fetchNews = category => {
    fetch(
      `http://www.newscout.in/api/v1/article/search/?domain=newscout&category=${category}`,
    )
      .then(res => res.json())
      .then(data => {
        const newsDataFetch = data.body.results;
        const finalNewsData = newsDataFetch
          .slice(0, PAGINATE_BY)
          .map(article => ({
            headline: article.title,
            image: { uri: article.cover_image },
            category: article.category,
            root_category: article.root_category,
            timestamp: article.published_on,
            tagline: 'Bruh Momento Oi Lorem Ipsum di rubi rabbi',
            id: article.id,
            slug: article.slug
          }));
        updateNewsByCategories(category, finalNewsData);
        // categories.forEach((category) => {setNews((prev) => ({...prev,[category]:json.body.results}))})
        return finalNewsData;
      })
      .catch(err => console.log(err))
      .finally(() => console.log('Fetch Category News Executed'));
  };

  const detailPageNavigation = (slug, id) => {
    navigation.push('NewsDetailPage', { articleId: id, articleSlug: slug })
  }


  useConstructor(() => {
    const cat_data = fetchCategories();
    //console.log(`construct ${categories}`)
    // for (let category in cat_data) {
    //     updateNewsByCategories(category,fetchNews(category))

    // }
  });

  // useEffect(() => {
  //     for (let category in cat_data) {
  //         fetchNews(category)

  //     }
  // })

  const styles = StyleSheet.create({
    categoriesTitle: {
      flexDirection: 'row',
      paddingTop: verticalScale(20),
      paddingHorizontal: horizontalScale(20),
    },
    categoriesTitleText: {
      flex: 1,
      fontFamily: fonts.type.semibold,
      fontSize: moderateScale(16),
      color: colors().recessive,
    },
    categoriesPillContainer: {
      paddingBottom: verticalScale(8),
      flexDirection: 'row',
      alignItems: 'space-between',
      paddingHorizontal: horizontalScale(16),
      backgroundColor: colors().dominant
    },
    container: {
      borderRadius: moderateScale(18),
      paddingVertical: verticalScale(8),
      paddingHorizontal: horizontalScale(16),
      backgroundColor: colors().dominant,
      width: 'auto',
    },
    selectedContainer: {
      paddingVertical: verticalScale(8),
      paddingHorizontal: horizontalScale(16),
      backgroundColor: colors().primaryColor,
      borderRadius: moderateScale(18),
      width: 'auto',
    },
    selectedPillText: {
      fontFamily: fonts.type.semibold,
      fontSize: moderateScale(12),
      color: colors().white,
    },
    pillText: {
      fontFamily: fonts.type.semibold,
      fontSize: moderateScale(12),
      color: colors().recessive,
    },
    categoriesNewsContainer: {
      paddingHorizontal: horizontalScale(16),
      paddingTop: verticalScale(10),
      backgroundColor: colors().dominant,
      gap: moderateScale(16),
      flexWrap: 'wrap',
      flexDirection: 'row'

    },
  });


  return (
    <View style={styles.categoriesContainer}>
      <SectionHeader label={'Categories'} />
      <View style={styles.categoriesPillContainer}>
        <ScrollView horizontal showsHorizontalScrollIndicator={false}>
          <ToggleButton.Group
            onValueChange={value => {
              setCategoryValue(value);
            }}>
            {categories.map(category => (
              <ToggleButton
                key={category}
                icon={() => (
                  <Text
                    style={[
                      category === categoryValue
                        ? styles.selectedPillText
                        : styles.pillText,
                    ]}>
                    {category}
                  </Text>
                )}
                style={[
                  category === categoryValue
                    ? styles.selectedContainer
                    : styles.container,
                  { marginHorizontal: horizontalScale(4) },
                ]}
                value={category}
              />
            ))}
          </ToggleButton.Group>
        </ScrollView>
      </View>
      <View><ScrollView showsVerticalScrollIndicator={false}>
        <View style={styles.categoriesNewsContainer}>
          {news[categoryValue] !== undefined ? (
            news[categoryValue].map(item => (
              <HorizontalNewsCardVariant
                headline={item.headline}
                image={item.image}
                timestamp={item.timestamp}
                tagline={item.tagline}
                onPress={() => detailPageNavigation(item.slug, item.id)}
              />
            ))
          ) : (
            <Text> News Not Present</Text>
          )}
        </View>
      </ScrollView></View>

    </View>
  );
};

export default CategorySection;

