import { ScrollView, StyleSheet, Text, View } from 'react-native'
import React, { useContext } from 'react'
import { horizontalScale, moderateScale, verticalScale } from '../../../constants/metrics'
import VerticalNewsCard from '../../molecules/Cards/VerticalNewsCard'
import { useConstructor } from '../../../constants/functions'
import SectionHeader from '../../molecules/Header/SectionHeader'
import { ThemeContext } from '../../../context/theme.context'
import colors from '../../../constants/colors'

const RecentPostsSection = () => {

  const theme = useContext(ThemeContext)
  const currentTheme = theme.state.theme

  const [posts, setPosts] = React.useState([{}, {}, {}, {}, {}])

  const fetchPosts = () => {
    fetch("http://www.newscout.in/api/v1/article/search/?domain=newscout&category=Sector%20Updates")
      .then((res) => res.json())
      .then((json) => {
        const postsFetched = json.body.results
        const finalPosts = postsFetched.map((item, index) => ({
          key: index,
          id: item.id,
          image: { uri: item.cover_image },
          author: item.author,
          headline: item.title
        }))
        setPosts(finalPosts)
        return postsFetched
      })
      .then((data) => {
        console.log(data[0].keys())
        return data
      })
      .catch((err) => console.log(err))
      .finally(() => console.log("Fetch Posts Executed"))
  }

  useConstructor(function () {
    const fetchPost = fetchPosts();
    console.log(fetchPost)
  })

  const styles = StyleSheet.create({
    recentPostsContainer: {
      paddingHorizontal: horizontalScale(16),
      gap: moderateScale(4),
      paddingBottom: verticalScale(16),
      backgroundColor: colors().dominant,
      flexDirection:'row'
    }
  })


  return (
    <View style={styles.container}>
      <SectionHeader label={"Recents Posts"} />
      <ScrollView horizontal showsHorizontalScrollIndicator={false}>
        <View style={styles.recentPostsContainer}>

          {posts.map((item) => <VerticalNewsCard
            key={item.key}
            id={item.id}
            image={item.image}
            author={item.author}
            headline={item.headline}
          />)}

        </View>
      </ScrollView>
    </View>
  )
}

export default RecentPostsSection

